<?php
/**
 * WP Customizer panel section to handle general design options
 *
 * @license For the full license information, please view the Licensing folder
 * that was distributed with this source code.
 *
 * @package Bimber_Theme
 */

// Prevent direct script access.
if ( ! defined( 'ABSPATH' ) ) {
	die( 'No direct script access allowed' );
}

$dev = defined( 'BTP_DEV' ) && BTP_DEV;
if ( ! $dev ) {
	return;
}

$bimber_option_name = bimber_get_theme_id();

$wp_customize->add_section( 'bimber_design_typo_section', array(
	'title'    => esc_html__( 'Typography', 'bimber' ),
	'priority' => 10,
	'panel'    => 'bimber_design_panel',
) );

// Body.
$wp_customize->add_setting( $bimber_option_name . '[typo_body]', array(
	'default'           => $bimber_customizer_defaults['typo_body'],
	'type'              => 'option',
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'sanitize_text_field',
	'transport'  		=> 'postMessage',
) );

$wp_customize->add_control( new Bimber_Customize_Typography_Control( $wp_customize, 'bimber_typo_body', array(
	'label'    => esc_html__( 'body', 'bimber' ),
	'section'  => 'bimber_design_typo_section',
	'settings' => $bimber_option_name . '[typo_body]',
	'input_attrs' => array(
		'selector' => 'html',
		'attributes' => array( 'font-family', 'font-style', 'font-size','line-height','letter-spacing','text-transform', 'font-size-tablet','line-height-tablet', 'font-size-mobile','line-height-mobile' ),
		'setting'	=> 'typo_body',
	),
) ) );

// Tags.
$wp_customize->add_setting( $bimber_option_name . '[typo_tags]', array(
	'default'           => $bimber_customizer_defaults['typo_tags'],
	'type'              => 'option',
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'sanitize_text_field',
	'transport'  		=> 'postMessage',
) );

$wp_customize->add_control( new Bimber_Customize_Typography_Control( $wp_customize, 'bimber_typo_tags', array(
	'label'    => esc_html__( 'Tags', 'bimber' ),
	'section'  => 'bimber_design_typo_section',
	'settings' => $bimber_option_name . '[typo_tags]',
	'input_attrs' => array(
		'selector' => '.entry-tag',
		'attributes' => array( 'font-family', 'font-style', 'font-size','line-height','letter-spacing','text-transform', 'font-size-tablet','line-height-tablet', 'font-size-mobile','line-height-mobile' ),
		'setting'	=> 'typo_tags',
	),
) ) );

// Categories.
$wp_customize->add_setting( $bimber_option_name . '[typo_categories]', array(
	'default'           => $bimber_customizer_defaults['typo_categories'],
	'type'              => 'option',
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'sanitize_text_field',
	'transport'  		=> 'postMessage',
) );

$wp_customize->add_control( new Bimber_Customize_Typography_Control( $wp_customize, 'bimber_typo_categories', array(
	'label'    => esc_html__( 'Categories', 'bimber' ),
	'section'  => 'bimber_design_typo_section',
	'settings' => $bimber_option_name . '[typo_categories]',
	'input_attrs' => array(
		'selector' => '.entry-category',
		'attributes' => array( 'font-family', 'font-style', 'font-size','line-height','letter-spacing','text-transform', 'font-size-tablet','line-height-tablet', 'font-size-mobile','line-height-mobile' ),
		'setting'	=> 'typo_categories',
	),
) ) );

// Tab.
$wp_customize->add_setting( $bimber_option_name . '[typo_tabs]', array(
	'default'           => $bimber_customizer_defaults['typo_tabs'],
	'type'              => 'option',
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'sanitize_text_field',
	'transport'  		=> 'postMessage',
) );

$wp_customize->add_control( new Bimber_Customize_Typography_Control( $wp_customize, 'bimber_typo_tabs', array(
	'label'    => esc_html__( 'Tabs', 'bimber' ),
	'section'  => 'bimber_design_typo_section',
	'settings' => $bimber_option_name . '[typo_tabs]',
	'input_attrs' => array(
		'selector' => '.g1-tab',
		'attributes' => array( 'font-family', 'font-style', 'font-size','line-height','letter-spacing','text-transform', 'font-size-tablet','line-height-tablet', 'font-size-mobile','line-height-mobile' ),
		'setting'	=> 'typo_tabs',
	),
) ) );

// Button medium.
$wp_customize->add_setting( $bimber_option_name . '[typo_button_m]', array(
	'default'           => $bimber_customizer_defaults['typo_button_m'],
	'type'              => 'option',
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'sanitize_text_field',
	'transport'  		=> 'postMessage',
) );

$wp_customize->add_control( new Bimber_Customize_Typography_Control( $wp_customize, 'bimber_typo_button_m', array(
	'label'    => esc_html__( 'Button Medium', 'bimber' ),
	'section'  => 'bimber_design_typo_section',
	'settings' => $bimber_option_name . '[typo_button_m]',
	'input_attrs' => array(
		'selector' => '.g1-button-m',
		'attributes' => array( 'font-family', 'font-style', 'font-size','line-height','letter-spacing','text-transform', 'font-size-tablet','line-height-tablet', 'font-size-mobile','line-height-mobile' ),
		'setting'	=> 'typo_button_m',
	),
) ) );

// g1-meta.
$wp_customize->add_setting( $bimber_option_name . '[typo_meta]', array(
	'default'           => $bimber_customizer_defaults['typo_meta'],
	'type'              => 'option',
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'sanitize_text_field',
	'transport'  		=> 'postMessage',
) );

$wp_customize->add_control( new Bimber_Customize_Typography_Control( $wp_customize, 'bimber_typo_meta', array(
	'label'    => esc_html__( 'Meta', 'bimber' ),
	'section'  => 'bimber_design_typo_section',
	'settings' => $bimber_option_name . '[typo_meta]',
	'input_attrs' => array(
		'selector' => '.g1-meta',
		'attributes' => array( 'font-family', 'font-style', 'font-size','line-height','letter-spacing','text-transform', 'font-size-tablet','line-height-tablet', 'font-size-mobile','line-height-mobile' ),
		'setting'	=> 'typo_meta',
		'attribute_args'	=> array(
			'font-size' => array(
				'min' => 12,
				'max' => 15,
			),
		),
	),
) ) );

// g1-link.
$wp_customize->add_setting( $bimber_option_name . '[typo_link]', array(
	'default'           => $bimber_customizer_defaults['typo_link'],
	'type'              => 'option',
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'sanitize_text_field',
	'transport'  		=> 'postMessage',
) );

$wp_customize->add_control( new Bimber_Customize_Typography_Control( $wp_customize, 'bimber_typo_link', array(
	'label'    => esc_html__( 'Meta link', 'bimber' ),
	'section'  => 'bimber_design_typo_section',
	'settings' => $bimber_option_name . '[typo_link]',
	'input_attrs' => array(
		'selector' => '.g1-link',
		'attributes' => array( 'font-family', 'font-style', 'font-size','line-height','letter-spacing','text-transform', 'font-size-tablet','line-height-tablet', 'font-size-mobile','line-height-mobile' ),
		'setting'	=> 'typo_link',
		'attribute_args'	=> array(
			'font-size' => array(
				'min' => 12,
				'max' => 15,
			),
		),
	),
) ) );

// Giga.
$wp_customize->add_setting( $bimber_option_name . '[typo_giga]', array(
	'default'           => $bimber_customizer_defaults['typo_giga'],
	'type'              => 'option',
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'sanitize_text_field',
	'transport'  		=> 'postMessage',
) );

$wp_customize->add_control( new Bimber_Customize_Typography_Control( $wp_customize, 'bimber_typo_giga', array(
	'label'    => esc_html__( 'Header: giga', 'bimber' ),
	'section'  => 'bimber_design_typo_section',
	'settings' => $bimber_option_name . '[typo_giga]',
	'input_attrs' => array(
		'selector' => '.g1-giga',
		'attributes' => array( 'font-family', 'font-style', 'font-size','line-height','letter-spacing','text-transform', 'font-size-tablet','line-height-tablet', 'font-size-mobile','line-height-mobile' ),
		'setting'	=> 'typo_giga',
	),
) ) );

// Giga-2nd.
$wp_customize->add_setting( $bimber_option_name . '[typo_giga_2nd]', array(
	'default'           => $bimber_customizer_defaults['typo_giga_2nd'],
	'type'              => 'option',
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'sanitize_text_field',
	'transport'  		=> 'postMessage',
) );

$wp_customize->add_control( new Bimber_Customize_Typography_Control( $wp_customize, 'bimber_typo_giga_2nd', array(
	'label'    => esc_html__( 'Header: giga-2nd', 'bimber' ),
	'section'  => 'bimber_design_typo_section',
	'settings' => $bimber_option_name . '[typo_giga_2nd]',
	'input_attrs' => array(
		'selector' => '.g1-giga-2nd',
		'attributes' => array( 'font-family', 'font-style', 'font-size','line-height','letter-spacing','text-transform', 'font-size-tablet','line-height-tablet', 'font-size-mobile','line-height-mobile' ),
		'setting'	=> 'typo_giga_2nd',
	),
) ) );

// mega.
$wp_customize->add_setting( $bimber_option_name . '[typo_mega]', array(
	'default'           => $bimber_customizer_defaults['typo_mega'],
	'type'              => 'option',
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'sanitize_text_field',
	'transport'  		=> 'postMessage',
) );

$wp_customize->add_control( new Bimber_Customize_Typography_Control( $wp_customize, 'bimber_typo_mega', array(
	'label'    => esc_html__( 'Header: mega', 'bimber' ),
	'section'  => 'bimber_design_typo_section',
	'settings' => $bimber_option_name . '[typo_mega]',
	'input_attrs' => array(
		'selector' => '.g1-mega',
		'attributes' => array( 'font-family', 'font-style', 'font-size','line-height','letter-spacing','text-transform', 'font-size-tablet','line-height-tablet', 'font-size-mobile','line-height-mobile' ),
		'setting'	=> 'typo_mega',
	),
) ) );

// mega-2nd.
$wp_customize->add_setting( $bimber_option_name . '[typo_mega_2nd]', array(
	'default'           => $bimber_customizer_defaults['typo_mega_2nd'],
	'type'              => 'option',
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'sanitize_text_field',
	'transport'  		=> 'postMessage',
) );

$wp_customize->add_control( new Bimber_Customize_Typography_Control( $wp_customize, 'bimber_typo_mega_2nd', array(
	'label'    => esc_html__( 'Header: mega-2nd', 'bimber' ),
	'section'  => 'bimber_design_typo_section',
	'settings' => $bimber_option_name . '[typo_mega_2nd]',
	'input_attrs' => array(
		'selector' => '.g1-mega-2nd',
		'attributes' => array( 'font-family', 'font-style', 'font-size','line-height','letter-spacing','text-transform', 'font-size-tablet','line-height-tablet', 'font-size-mobile','line-height-mobile' ),
		'setting'	=> 'typo_mega_2nd',
	),
) ) );

// beta.
$wp_customize->add_setting( $bimber_option_name . '[typo_beta]', array(
	'default'           => $bimber_customizer_defaults['typo_beta'],
	'type'              => 'option',
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'sanitize_text_field',
	'transport'  		=> 'postMessage',
) );

$wp_customize->add_control( new Bimber_Customize_Typography_Control( $wp_customize, 'bimber_typo_beta', array(
	'label'    => esc_html__( 'Header: beta', 'bimber' ),
	'section'  => 'bimber_design_typo_section',
	'settings' => $bimber_option_name . '[typo_beta]',
	'input_attrs' => array(
		'selector' => '.g1-beta',
		'attributes' => array( 'font-family', 'font-style', 'font-size','line-height','letter-spacing','text-transform', 'font-size-tablet','line-height-tablet', 'font-size-mobile','line-height-mobile' ),
		'setting'	=> 'typo_beta',
	),
) ) );

// beta-2nd.
$wp_customize->add_setting( $bimber_option_name . '[typo_beta_2nd]', array(
	'default'           => $bimber_customizer_defaults['typo_beta_2nd'],
	'type'              => 'option',
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'sanitize_text_field',
	'transport'  		=> 'postMessage',
) );

$wp_customize->add_control( new Bimber_Customize_Typography_Control( $wp_customize, 'bimber_typo_beta_2nd', array(
	'label'    => esc_html__( 'Header: beta-2nd', 'bimber' ),
	'section'  => 'bimber_design_typo_section',
	'settings' => $bimber_option_name . '[typo_beta_2nd]',
	'input_attrs' => array(
		'selector' => '.g1-beta-2nd',
		'attributes' => array( 'font-family', 'font-style', 'font-size','line-height','letter-spacing','text-transform', 'font-size-tablet','line-height-tablet', 'font-size-mobile','line-height-mobile' ),
		'setting'	=> 'typo_beta_2nd',
	),
) ) );

// gamma.
$wp_customize->add_setting( $bimber_option_name . '[typo_gamma]', array(
	'default'           => $bimber_customizer_defaults['typo_gamma'],
	'type'              => 'option',
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'sanitize_text_field',
	'transport'  		=> 'postMessage',
) );

$wp_customize->add_control( new Bimber_Customize_Typography_Control( $wp_customize, 'bimber_typo_gamma', array(
	'label'    => esc_html__( 'Header: gamma', 'bimber' ),
	'section'  => 'bimber_design_typo_section',
	'settings' => $bimber_option_name . '[typo_gamma]',
	'input_attrs' => array(
		'selector' => '.g1-gamma',
		'attributes' => array( 'font-family', 'font-style', 'font-size','line-height','letter-spacing','text-transform', 'font-size-tablet','line-height-tablet', 'font-size-mobile','line-height-mobile' ),
		'setting'	=> 'typo_gamma',
	),
) ) );

// gamma-2nd.
$wp_customize->add_setting( $bimber_option_name . '[typo_gamma_2nd]', array(
	'default'           => $bimber_customizer_defaults['typo_gamma_2nd'],
	'type'              => 'option',
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'sanitize_text_field',
	'transport'  		=> 'postMessage',
) );

$wp_customize->add_control( new Bimber_Customize_Typography_Control( $wp_customize, 'bimber_typo_gamma_2nd', array(
	'label'    => esc_html__( 'Header: gamma-2nd', 'bimber' ),
	'section'  => 'bimber_design_typo_section',
	'settings' => $bimber_option_name . '[typo_gamma_2nd]',
	'input_attrs' => array(
		'selector' => '.g1-gamma-2nd',
		'attributes' => array( 'font-family', 'font-style', 'font-size','line-height','letter-spacing','text-transform', 'font-size-tablet','line-height-tablet', 'font-size-mobile','line-height-mobile' ),
		'setting'	=> 'typo_gamma_2nd',
	),
) ) );

// delta.
$wp_customize->add_setting( $bimber_option_name . '[typo_delta]', array(
	'default'           => $bimber_customizer_defaults['typo_delta'],
	'type'              => 'option',
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'sanitize_text_field',
	'transport'  		=> 'postMessage',
) );

$wp_customize->add_control( new Bimber_Customize_Typography_Control( $wp_customize, 'bimber_typo_delta', array(
	'label'    => esc_html__( 'Header: delta', 'bimber' ),
	'section'  => 'bimber_design_typo_section',
	'settings' => $bimber_option_name . '[typo_delta]',
	'input_attrs' => array(
		'selector' => '.g1-delta',
		'attributes' => array( 'font-family', 'font-style', 'font-size','line-height','letter-spacing','text-transform', 'font-size-tablet','line-height-tablet', 'font-size-mobile','line-height-mobile' ),
		'setting'	=> 'typo_delta',
	),
) ) );

// delta-2nd.
$wp_customize->add_setting( $bimber_option_name . '[typo_delta_2nd]', array(
	'default'           => $bimber_customizer_defaults['typo_delta_2nd'],
	'type'              => 'option',
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'sanitize_text_field',
	'transport'  		=> 'postMessage',
) );

$wp_customize->add_control( new Bimber_Customize_Typography_Control( $wp_customize, 'bimber_typo_delta_2nd', array(
	'label'    => esc_html__( 'Header: delta-2nd', 'bimber' ),
	'section'  => 'bimber_design_typo_section',
	'settings' => $bimber_option_name . '[typo_delta_2nd]',
	'input_attrs' => array(
		'selector' => '.g1-delta-2nd',
		'attributes' => array( 'font-family', 'font-style', 'font-size','line-height','letter-spacing','text-transform', 'font-size-tablet','line-height-tablet', 'font-size-mobile','line-height-mobile' ),
		'setting'	=> 'typo_delta_2nd',
	),
) ) );

// epsilon.
$wp_customize->add_setting( $bimber_option_name . '[typo_epsilon]', array(
	'default'           => $bimber_customizer_defaults['typo_epsilon'],
	'type'              => 'option',
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'sanitize_text_field',
	'transport'  		=> 'postMessage',
) );

$wp_customize->add_control( new Bimber_Customize_Typography_Control( $wp_customize, 'bimber_typo_epsilon', array(
	'label'    => esc_html__( 'Header: epsilon', 'bimber' ),
	'section'  => 'bimber_design_typo_section',
	'settings' => $bimber_option_name . '[typo_epsilon]',
	'input_attrs' => array(
		'selector' => '.g1-epsilon',
		'attributes' => array( 'font-family', 'font-style', 'font-size','line-height','letter-spacing','text-transform', 'font-size-tablet','line-height-tablet', 'font-size-mobile','line-height-mobile' ),
		'setting'	=> 'typo_epsilon',
	),
) ) );

// epsilon-2nd.
$wp_customize->add_setting( $bimber_option_name . '[typo_epsilon_2nd]', array(
	'default'           => $bimber_customizer_defaults['typo_epsilon_2nd'],
	'type'              => 'option',
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'sanitize_text_field',
	'transport'  		=> 'postMessage',
) );

$wp_customize->add_control( new Bimber_Customize_Typography_Control( $wp_customize, 'bimber_typo_epsilon_2nd', array(
	'label'    => esc_html__( 'Header: epsilon-2nd', 'bimber' ),
	'section'  => 'bimber_design_typo_section',
	'settings' => $bimber_option_name . '[typo_epsilon_2nd]',
	'input_attrs' => array(
		'selector' => '.g1-epsilon-2nd',
		'attributes' => array( 'font-family', 'font-style', 'font-size','line-height','letter-spacing','text-transform', 'font-size-tablet','line-height-tablet', 'font-size-mobile','line-height-mobile' ),
		'setting'	=> 'typo_epsilon_2nd',
	),
) ) );

// zeta.
$wp_customize->add_setting( $bimber_option_name . '[typo_zeta]', array(
	'default'           => $bimber_customizer_defaults['typo_zeta'],
	'type'              => 'option',
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'sanitize_text_field',
	'transport'  		=> 'postMessage',
) );

$wp_customize->add_control( new Bimber_Customize_Typography_Control( $wp_customize, 'bimber_typo_zeta', array(
	'label'    => esc_html__( 'Header: zeta', 'bimber' ),
	'section'  => 'bimber_design_typo_section',
	'settings' => $bimber_option_name . '[typo_zeta]',
	'input_attrs' => array(
		'selector' => '.g1-zeta',
		'attributes' => array( 'font-family', 'font-style', 'font-size','line-height','letter-spacing','text-transform', 'font-size-tablet','line-height-tablet', 'font-size-mobile','line-height-mobile' ),
		'setting'	=> 'typo_zeta',
	),
) ) );

// zeta-2nd.
$wp_customize->add_setting( $bimber_option_name . '[typo_zeta_2nd]', array(
	'default'           => $bimber_customizer_defaults['typo_zeta_2nd'],
	'type'              => 'option',
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'sanitize_text_field',
	'transport'  		=> 'postMessage',
) );

$wp_customize->add_control( new Bimber_Customize_Typography_Control( $wp_customize, 'bimber_typo_zeta_2nd', array(
	'label'    => esc_html__( 'Header: zeta-2nd', 'bimber' ),
	'section'  => 'bimber_design_typo_section',
	'settings' => $bimber_option_name . '[typo_zeta_2nd]',
	'input_attrs' => array(
		'selector' => '.g1-zeta-2nd',
		'attributes' => array( 'font-family', 'font-style', 'font-size','line-height','letter-spacing','text-transform', 'font-size-tablet','line-height-tablet', 'font-size-mobile','line-height-mobile' ),
		'setting'	=> 'typo_zeta_2nd',
	),
) ) );